# deployment_strategy

Source: [import_pkg/apps/deployment_strategy.k](https://url/to/source_code/import_pkg/apps/deployment_strategy.k)

This is the deployment\_strategy module in kusion\_kubernetes.api.apps.v1 package.<br />This file was generated by the KCL auto-gen tool. DO NOT EDIT.<br />Editing this file might prove futile when you re-run the KCL auto-gen generate command.

## Schema DeploymentStrategy

DeploymentStrategy describes how to replace existing pods with new ones.

### Attributes

|Name and Description|Type|Default Value|Required|
|--------------------|----|-------------|--------|
|**type**<br />Type of deployment. Can be "Recreate" or "RollingUpdate". Default is RollingUpdate.|str|Undefined|optional|
|**rollingUpdate**<br />Rolling update config params. Present only if DeploymentStrategyType = RollingUpdate.|[RollingUpdateDeployment](doc_rolling_update_deployment_en#schema-rollingupdatedeployment)|Undefined|optional|
<!-- Auto generated by kcl-doc tool, please do not edit. -->
